@@ -14,10 +14,3 @@ class TopicForm(forms.Form):
 
     subject = forms.CharField(max_length=100)
     message = forms.CharField(widget=forms.Textarea)
-
-
-class UserProfileForm(forms.ModelForm):
-
-    class Meta:
-        model = mymodels.UserProfile
-        exclude = ('user',)
