@@ -218,6 +218,9 @@ class TopicDelete(DeleteView):
         topic = get_object_or_404(mymodels.Topic, slug=self.kwargs['topicslug'])
         topic.status=0
         topic.save()
+        log = mymodels.Log(user=request.user)
+        log.action = "%s - [DEL] topic '%s' (status=0)" % (request.user, topic)
+        log.save(commit=False)
         #topic.delete()
         return redirect('app_forum-forum-detail', topic.forum.slug)
 
